import { InjectionToken } from '@angular/core';
import { DateAdapter } from '@angular/material/core';
import { Dayjs } from 'dayjs';
export interface DayJsDateAdapterOptions {
    /**
     * Turns the use of utc dates on or off.
     * Changing this will change how Angular Material components like DatePicker output dates.
     * {@default false}
     */
    useUtc?: boolean;
}
/** InjectionToken for Dayjs date adapter to configure options. */
export declare const MAT_DAYJS_DATE_ADAPTER_OPTIONS: InjectionToken<DayJsDateAdapterOptions>;
export declare function MAT_DAYJS_DATE_ADAPTER_OPTIONS_FACTORY(): DayJsDateAdapterOptions;
/** Adapts Dayjs Dates for use with Angular Material. */
export declare class DayjsDateAdapter extends DateAdapter<Dayjs> {
    dateLocale: string;
    private options?;
    private localeData;
    constructor(dateLocale: string, options?: DayJsDateAdapterOptions);
    setLocale(locale: string): void;
    getYear(date: Dayjs): number;
    getMonth(date: Dayjs): number;
    getDate(date: Dayjs): number;
    getDayOfWeek(date: Dayjs): number;
    getMonthNames(style: 'long' | 'short' | 'narrow'): string[];
    getDateNames(): string[];
    getDayOfWeekNames(style: 'long' | 'short' | 'narrow'): string[];
    getYearName(date: Dayjs): string;
    getFirstDayOfWeek(): number;
    getNumDaysInMonth(date: Dayjs): number;
    clone(date: Dayjs): Dayjs;
    createDate(year: number, month: number, date: number): Dayjs;
    today(): Dayjs;
    parse(value: any, parseFormat: string): Dayjs | null;
    format(date: Dayjs, displayFormat: string): string;
    addCalendarYears(date: Dayjs, years: number): Dayjs;
    addCalendarMonths(date: Dayjs, months: number): Dayjs;
    addCalendarDays(date: Dayjs, days: number): Dayjs;
    toIso8601(date: Dayjs): string;
    /**
     * Attempts to deserialize a value to a valid date object. This is different from parsing in that
     * deserialize should only accept non-ambiguous, locale-independent formats (e.g. a ISO 8601
     * string). The default implementation does not allow any deserialization, it simply checks that
     * the given value is already a valid date object or null. The `<mat-datepicker>` will call this
     * method on all of it's `@Input()` properties that accept dates. It is therefore possible to
     * support passing values from your backend directly to these properties by overriding this method
     * to also deserialize the format used by your backend.
     * @param value The value to be deserialized into a date object.
     * @returns The deserialized date object, either a valid date, null if the value can be
     *     deserialized into a null date (e.g. the empty string), or an invalid date.
     */
    deserialize(value: any): Dayjs | null;
    isDateInstance(obj: any): boolean;
    isValid(date: Dayjs): boolean;
    invalid(): Dayjs;
    private dayJs;
    private get shouldUseUtc();
    private initializeParser;
}
